#!/bin/bash
[ "$1" = "" ] && export TYPE="--mitaka" || export TYPE="$1"

if [ "$TYPE" = "--mitaka" ]; then
  export URL="https://repos.fedorapeople.org/repos/openstack/openstack-mitaka/rdo-release-mitaka-5.noarch.rpm"
  export ANSWER="packstack-answers-multinode.txt"
elif [ "$TYPE" = "--liberty" ]; then
  export URL="https://repos.fedorapeople.org/repos/openstack/openstack-liberty/rdo-release-liberty-5.noarch.rpm"
  export ANSWER="packstack-answers-multinode.txt"
elif [ "$TYPE" = "--kilo" ]; then
  export URL="https://repos.fedorapeople.org/repos/openstack/openstack-kilo/rdo-release-kilo-2.noarch.rpm"
  export ANSWER="packstack-answers-multinode.txt"
else
  echo "Unknown OpenStack version." && exit 1
fi

cat <<EOF
##################################################
### setting up nodes for `echo $TYPE|cut -d\- -f3`

EOF

echo "Achtung. Um Komplikationen zu vermeiden, wird SELinux in den Modus \"permissive\" versetzt."
setenforce 0

for o in {0..4}; do
  export VENAME=oslnode$o
  [ "$o" = "0" ] && export VENAME=oslcontroller
  [ "$o" = "4" ] && export VENAME=oslnet
  export VEID="140$o"
  echo "##################################################"
  echo "### setting up $VENAME ($VEID)"
  source /etc/vz/vz.conf
  ssh -oStrictHostKeyChecking=no root@$VENAME <<EOF
  yum -y install deltarpm
  yum -y install epel-release screen lvm2 rsync bind-utils redhat-lsb-core wget net-tools bash-completion audit sysfsutils selinux-policy-targeted
# htop python-netaddr openssh-clients openssh-server xorg-x11-xauth rsync bind-utils nc tcpdump bridge-utils yum-utils lsof e2fsprogs
  sed -i -e "s/SELINUX=enforcing/SELINUX=permissive/" /etc/selinux/config
  setenforce 0
  yum -y upgrade
  yum -y remove NetworkManager
  yum install -y $URL

  # definitely disable auditd
  sed -i -e "s/^Exec/#Exec/g" /usr/lib/systemd/system/auditd.service
  sed -i -e "s/^#ExecStart=.*/ExecStart=\/bin\/true/" /usr/lib/systemd/system/auditd.service
  ln -sf /usr/lib/systemd/system/auditd.service /etc/systemd/system/multi-user.target.wants/auditd.service
  systemctl daemon-reload

  # we sometimes have a problem with sysctl and return values so we replace it
  [ ! -e /sbin/sysctl.org ] && mv /sbin/sysctl /sbin/sysctl.org
  echo -e '#!/bin/bash\n/sbin/sysctl.org \$@\nexit 0\n' > /sbin/sysctl
  chmod 755 /sbin/sysctl

  # remove erraneous entries in sysctl.conf to prevent errors during installation
  for n in \`sysctl -p 2>&1|grep error|cut -d\" -f2\`; do echo \$n;sed -i -e "s/^\$n\ *=.*\$//" /etc/sysctl.conf; done

  # we sometimes have a problem with modprobe and return values so we replace it
  [ ! -e /sbin/modprobe.org ] && mv /sbin/modprobe /sbin/modprobe.org
  cat <<END >/sbin/modprobe
#!/bin/bash
[ "\\\$1" = "--version" ] && /bin/kmod --version && exit 0
logger "modprobe was called to load kernel module \\\$@"
logger "You have to execute \"\\\$0 \\\$@\" at your host to have the approprate functionality in the container."
exit 0
END
  chmod 755 /sbin/modprobe
  [ ! -e /sbin/insmod.org ] && mv /sbin/insmod /sbin/insmod.org
  ln /sbin/modprobe /sbin/insmod

  # since December 2014 selinux is used in OpenStack, so we have to simulate this
  for binary in getsebool setsebool; do
    [ ! -e /sbin/\${binary}.org ] && mv /sbin/\${binary} /sbin/\${binary}.org
    echo -e '#!/bin/bash\necho "\$1 --> on"\nexit 0\n' > /sbin/\${binary}
    chmod 755 /sbin/\${binary}
  done
  
  # we do not want to have sound...
  systemctl stop sound
  systemctl disable sound

  # things for the controller only
  if [ "$VENAME" = "oslcontroller" ]; then
    # patch iSCSI target
    yum -y install python-rtslib
    sed -i -e "s/modprobe(/#modprobe(/g" /usr/lib/python2.7/site-packages/rtslib/root.py
    sed -i -e "s/kmod.Kmod().modprobe(module)/#kmod.Kmod().modprobe(module)/g" /usr/lib/python2.7/site-packages/rtslib_fb/utils.py
    # install the packstack installer
    yum -y install openstack-packstack
    if [ "$TYPE" = "--mitaka" ]; then
      mv /usr/lib/python2.7/site-packages/packstack/puppet/templates/prescript.pp /usr/lib/python2.7/site-packages/packstack/puppet/templates/prescript.pp.org
      head -n -12 /usr/lib/python2.7/site-packages/packstack/puppet/templates/prescript.pp.org > /usr/lib/python2.7/site-packages/packstack/puppet/templates/prescript.pp
    fi
  fi

  # inhibit usage of hiera version in epel
  sed -i -e "s/^\(\[epel\]\)$/\1\nexclude=hiera*/" /etc/yum.repos.d/epel.repo

EOF
done

scp packstack-answers-multinode.txt root@oslcontroller:

cat <<EOF

=========================================================================================
Zum Start der Installation von OpenStack bitte das Folgende, bevorzugt in
einer "screen" Session, als root auf *oslcontroller* ausführen:

   packstack --answer-file=packstack-answers-multinode.txt 2>&1 |tee -a /root/install.out

Gibt es einen Fehler, kann der Befehl nach Ausräumen der gemeldeten
Fehlerursache einfach wiederholt werden.
EOF
